@@ -34,12 +34,24 @@ irs <- function(sframe, n_base, stratum_var = NULL, seltype = NULL, caty_var = N
                 legacy_sites = NULL, legacy_stratum_var = NULL,
                 legacy_caty_var = NULL, legacy_aux_var = NULL, mindis = NULL,
                 maxtry = 10, n_over = NULL, n_near = NULL, wgt_units = NULL,
-                pt_density = NULL, DesignID = "Site", SiteBegin = 1, sep = "-") {
+                pt_density = NULL, DesignID = "Site", SiteBegin = 1, sep = "-", projcrs_check = TRUE) {
   if (inherits(sframe, c("tbl_df", "tbl"))) { # identify if tibble class elements are present
     class(sframe) <- setdiff(class(sframe), c("tbl_df", "tbl"))
     # remove tibble class for rownames warning
   }
 
+  if (!is.null(legacy_sites) & inherits(legacy_sites, c("tbl_df", "tbl"))) { # identify if tibble class elements are present
+    class(legacy_sites) <- setdiff(class(legacy_sites), c("tbl_df", "tbl"))
+    # remove tibble class for rownames warning
+  }
+
+  if (!is.null(legacy_sites)) {
+    sframe_geom_name <- attr(sframe, "sf_column")
+    legacy_geom_name <- attr(legacy_sites, "sf_column")
+    names(legacy_sites)[names(legacy_sites) == legacy_geom_name] <- sframe_geom_name
+    st_geometry(legacy_sites) <- sframe_geom_name
+  }
+
   # Create warning indicator and data frame to collect all potential issues during
   # sample selection
   warn_ind <- FALSE
@@ -59,8 +71,8 @@ irs <- function(sframe, n_base, stratum_var = NULL, seltype = NULL, caty_var = N
 
   # Drop m and z values to ensure no issues with grts functionality with sf object
   if (!is.null(st_m_range(sframe)) | !is.null(st_z_range(sframe))) {
-    warn_ind <- TRUE
-    warn_df$warn <- "\nThe survey frame object passed to function grts contains m or z values - they are being dropped to ensure functionality in grts."
+    # warn_ind <- TRUE
+    # warn_df$warn <- "\nThe survey frame object passed to function grts contains m or z values - they are being dropped to ensure functionality in grts."
     sframe <- st_zm(sframe)
   }
 
@@ -98,8 +110,10 @@ irs <- function(sframe, n_base, stratum_var = NULL, seltype = NULL, caty_var = N
     legacy_option = legacy_option, stratum = stratum, seltype = seltype,
     n_base = n_base, caty_n = caty_n, n_over = n_over, n_near = n_near,
     stratum_var = stratum_var, caty_var = caty_var, aux_var = aux_var,
+    legacy_stratum_var = legacy_stratum_var, legacy_caty_var = legacy_caty_var,
+    legacy_aux_var = legacy_aux_var,
     legacy_var = legacy_var, mindis = mindis, DesignID = DesignID,
-    SiteBegin = SiteBegin, maxtry = maxtry
+    SiteBegin = SiteBegin, maxtry = maxtry, projcrs_check = projcrs_check
   )
 
   # preserve original sframe names
@@ -306,6 +320,11 @@ irs <- function(sframe, n_base, stratum_var = NULL, seltype = NULL, caty_var = N
     }
   }
 
+  # spelling change to avoid clash with analysis warnings
+  if (!is.null(warn_df) && "warning" %in% names(warn_df)) {
+    names(warn_df)[which(names(warn_df) == "warning")] <- "Warning"
+  }
+
   # Create a siteID for all sites
   ntot <- NROW(sites_legacy) + NROW(sites_base) + NROW(sites_over) + NROW(sites_near)
   siteID <- gsub(" ", "0", paste0(DesignID, sep, format(SiteBegin - 1 + 1:ntot, sep = "")))
@@ -343,6 +362,12 @@ irs <- function(sframe, n_base, stratum_var = NULL, seltype = NULL, caty_var = N
 
   # if n_near sample sites, assign base ids to the replacement sites. then add siteIDs
   if (!is.null(n_near)) {
+    tst <- match(paste(sites_near$stratum, sites_near$replsite, sep = "_"),
+      paste(sites_legacy$stratum, sites_legacy$idpts, sep = "_"),
+      nomatch = 0
+    )
+    sites_near$replsite[tst > 0] <- sites_legacy$siteID[tst]
+
     tst <- match(paste(sites_near$stratum, sites_near$replsite, sep = "_"),
       paste(sites_base$stratum, sites_base$idpts, sep = "_"),
       nomatch = 0
@@ -361,33 +386,62 @@ irs <- function(sframe, n_base, stratum_var = NULL, seltype = NULL, caty_var = N
     sites_near$siteID <- siteID[(nlast + 1):(nlast + nrow(sites_near))]
   }
 
-  # Add lat/lon in WGS84
-  if (!is.null(sites_legacy)) {
-    sites_legacy$lon_WGS84 <- st_coordinates(st_transform(sites_legacy, crs = 4326))[, "X"]
-    sites_legacy$lat_WGS84 <- st_coordinates(st_transform(sites_legacy, crs = 4326))[, "Y"]
-  }
-  if (!is.null(sites_base)) {
-    sites_base$lon_WGS84 <- st_coordinates(st_transform(sites_base, crs = 4326))[, "X"]
-    sites_base$lat_WGS84 <- st_coordinates(st_transform(sites_base, crs = 4326))[, "Y"]
-  }
-  if (!is.null(sites_over)) {
-    sites_over$lon_WGS84 <- st_coordinates(st_transform(sites_over, crs = 4326))[, "X"]
-    sites_over$lat_WGS84 <- st_coordinates(st_transform(sites_over, crs = 4326))[, "Y"]
-  }
-  if (!is.null(sites_near)) {
-    sites_near$lon_WGS84 <- st_coordinates(st_transform(sites_near, crs = 4326))[, "X"]
-    sites_near$lat_WGS84 <- st_coordinates(st_transform(sites_near, crs = 4326))[, "Y"]
-  }
+  # Add lat/lon in WGS84 or X/Y coordinates
+  if (is.na(st_crs(sites_base)) | st_is_longlat(sites_base)) {
+    if (!is.null(sites_legacy)) {
+      sites_legacy$X <- st_coordinates(sites_legacy)[, "X"]
+      sites_legacy$Y <- st_coordinates(sites_legacy)[, "Y"]
+    }
 
+    if (!is.null(sites_base)) {
+      sites_base$X <- st_coordinates(sites_base)[, "X"]
+      sites_base$Y <- st_coordinates(sites_base)[, "Y"]
+    }
 
-  # reorder sf object variables by first specifying design names excluding unique
-  # feature ID id and idpts as they are internal
-  # reorder sf object variables by first specifying design names excluding unique
-  # feature ID id and idpts as they are internal
-  dsgn_names <- c(
-    "siteID", "siteuse", "replsite", "lon_WGS84", "lat_WGS84",
-    "stratum", "wgt", "ip", "caty", "aux"
-  )
+    if (!is.null(sites_over)) {
+      sites_over$X <- st_coordinates(sites_over)[, "X"]
+      sites_over$Y <- st_coordinates(sites_over)[, "Y"]
+    }
+
+    if (!is.null(sites_near)) {
+      sites_near$X <- st_coordinates(sites_near)[, "X"]
+      sites_near$Y <- st_coordinates(sites_near)[, "Y"]
+    }
+
+    # reorder sf object variables by first specifying design names excluding unique
+    # feature ID id and idpts as they are internal
+    dsgn_names <- c(
+      "siteID", "siteuse", "replsite", "X", "Y",
+      "stratum", "wgt", "ip", "caty", "aux"
+    )
+  } else {
+    if (!is.null(sites_legacy)) {
+      sites_legacy$lon_WGS84 <- st_coordinates(st_transform(sites_legacy, crs = 4326))[, "X"]
+      sites_legacy$lat_WGS84 <- st_coordinates(st_transform(sites_legacy, crs = 4326))[, "Y"]
+    }
+
+    if (!is.null(sites_base)) {
+      sites_base$lon_WGS84 <- st_coordinates(st_transform(sites_base, crs = 4326))[, "X"]
+      sites_base$lat_WGS84 <- st_coordinates(st_transform(sites_base, crs = 4326))[, "Y"]
+    }
+
+    if (!is.null(sites_over)) {
+      sites_over$lon_WGS84 <- st_coordinates(st_transform(sites_over, crs = 4326))[, "X"]
+      sites_over$lat_WGS84 <- st_coordinates(st_transform(sites_over, crs = 4326))[, "Y"]
+    }
+
+    if (!is.null(sites_near)) {
+      sites_near$lon_WGS84 <- st_coordinates(st_transform(sites_near, crs = 4326))[, "X"]
+      sites_near$lat_WGS84 <- st_coordinates(st_transform(sites_near, crs = 4326))[, "Y"]
+    }
+
+    # reorder sf object variables by first specifying design names excluding unique
+    # feature ID id and idpts as they are internal
+    dsgn_names <- c(
+      "siteID", "siteuse", "replsite", "lon_WGS84", "lat_WGS84",
+      "stratum", "wgt", "ip", "caty", "aux"
+    )
+  }
 
   dsgn_names_extra <- c(dsgn_names, "xcoord", "ycoord", "idpts")
 
